#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Change bar color according to H/L to Close relationship
    /// </summary>
    [Description(@"Change bar color according to Prior High/Low to Close relationship")]
    [Gui.Design.DisplayName(@"Color Bar on H/L to Close")]
    public class ColorBar_HLtoClose : Indicator
    {

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
			AutoScale = false;
            Overlay				= true;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if(CurrentBar<3) return;

			if(Close[0] > High[1]) BarColor = pUc;
			else if(Close[0] < Low[1]) BarColor = pDc;
			else BarColor = pNeutral;

		}

		
		private Color pDc = Color.Red;
		[XmlIgnore()]
		[Description("Color of bar when Close is below prior low")]
		[Category("Visual")]
		[Gui.Design.DisplayNameAttribute("Down Close")]
		public Color DC{	get { return pDc; }	set { pDc = value; }		}
		[Browsable(false)]
		public string DClSerialize
		{	get { return NinjaTrader.Gui.Design.SerializableColor.ToString(pDc); } set { pDc = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
		}
		
		private Color pUc = Color.Green;
		[XmlIgnore()]
		[Description("Color of bar when Close is above prior High")]
		[Category("Visual")]
		[Gui.Design.DisplayNameAttribute("Up Close")]
		public Color UC{	get { return pUc; }	set { pUc = value; }		}
		[Browsable(false)]
		public string UClSerialize
		{	get { return NinjaTrader.Gui.Design.SerializableColor.ToString(pUc); } set { pUc = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
		}
		
		private Color pNeutral = Color.Black;
		[XmlIgnore()]
		[Description("")]
		[Category("Visual")]
		[Gui.Design.DisplayNameAttribute("Neutral Close")]
		public Color NeutralColor{	get { return pNeutral; }	set { pNeutral = value; }		}
		[Browsable(false)]
		public string NeutralClSerialize
		{	get { return NinjaTrader.Gui.Design.SerializableColor.ToString(pNeutral); } set { pNeutral = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
		}
    }
}


